@@ -83,6 +83,22 @@ test_virtualenvwrapper_show_workon_options_grep_options () {
     rm -f "$WORKON_HOME/link_env"
 }
 
+test_virtualenvwrapper_show_workon_options_chpwd () {
+    # https://bitbucket.org/dhellmann/virtualenvwrapper/issue/153
+    function chpwd {
+        local SEARCH=' '
+        local REPLACE='%20'
+        local PWD_URL="file://$HOSTNAME${PWD//$SEARCH/$REPLACE}"
+        printf '\e]7;%s\a' "$PWD_URL"
+        echo -n "\033]0;${HOST//.*}:$USER\007"
+    }
+    mkdir "$WORKON_HOME/not_env"
+    envs=$(virtualenvwrapper_show_workon_options | tr '\n' ' ')
+    assertSame "env1 env2 " "$envs"
+    rmdir "$WORKON_HOME/not_env"
+    rm -f "$WORKON_HOME/link_env"
+}
+
 test_virtualenvwrapper_show_workon_options_no_envs () {
     old_home="$WORKON_HOME"
     export WORKON_HOME=${TMPDIR:-/tmp}/$$
